For each grid counts the number of observations in that
grid. Have to pass in grid object so that can get
the empty grid cells.
Usage
count_grid_behaviour(grid, zoo_grid)
Arguments
- grid
grid object
- zoo_grid
zoo grid object
Value
tibble with grid number and number of obs
Examples
count_grid_behaviour(grid, skink_grid)
#> # A tibble: 16 × 2
#> grid obs
#> <dbl> <dbl>
#> 1 1 51
#> 2 2 917
#> 3 3 1077
#> 4 4 13
#> 5 5 551
#> 6 6 905
#> 7 7 2554
#> 8 8 295
#> 9 9 37
#> 10 10 86
#> 11 11 156
#> 12 12 68
#> 13 13 0
#> 14 14 12
#> 15 15 6
#> 16 16 0